==> huaweicloudsdkdgc-3.1.6-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/show_resource_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResourceResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'type': 'str',
        'location': 'str',
        'depend_files': 'list[str]',
        'desc': 'str',
        'directory': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'location': 'location',
        'depend_files': 'dependFiles',
        'desc': 'desc',
        'directory': 'directory'
    }

    def __init__(self, name=None, type=None, location=None, depend_files=None, desc=None, directory=None):
        """ShowResourceResponse

        The model defined in huaweicloud sdk

        :param name: 
        :type name: str
        :param type: 
        :type type: str
        :param location: 资源文件所在OBS路径
        :type location: str
        :param depend_files: 
        :type depend_files: list[str]
        :param desc: 
        :type desc: str
        :param directory: 资源所在目录
        :type directory: str
        """
        
        super(ShowResourceResponse, self).__init__()

        self._name = None
        self._type = None
        self._location = None
        self._depend_files = None
        self._desc = None
        self._directory = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if location is not None:
            self.location = location
        if depend_files is not None:
            self.depend_files = depend_files
        if desc is not None:
            self.desc = desc
        if directory is not None:
            self.directory = directory

    @property
    def name(self):
        """Gets the name of this ShowResourceResponse.


        :return: The name of this ShowResourceResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShowResourceResponse.


        :param name: The name of this ShowResourceResponse.
        :type name: str
        """
        self._name = name

    @property
    def type(self):
        """Gets the type of this ShowResourceResponse.


        :return: The type of this ShowResourceResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowResourceResponse.


        :param type: The type of this ShowResourceResponse.
        :type type: str
        """
        self._type = type

    @property
    def location(self):
        """Gets the location of this ShowResourceResponse.

        资源文件所在OBS路径

        :return: The location of this ShowResourceResponse.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ShowResourceResponse.

        资源文件所在OBS路径

        :param location: The location of this ShowResourceResponse.
        :type location: str
        """
        self._location = location

    @property
    def depend_files(self):
        """Gets the depend_files of this ShowResourceResponse.


        :return: The depend_files of this ShowResourceResponse.
        :rtype: list[str]
        """
        return self._depend_files

    @depend_files.setter
    def depend_files(self, depend_files):
        """Sets the depend_files of this ShowResourceResponse.


        :param depend_files: The depend_files of this ShowResourceResponse.
        :type depend_files: list[str]
        """
        self._depend_files = depend_files

    @property
    def desc(self):
        """Gets the desc of this ShowResourceResponse.


        :return: The desc of this ShowResourceResponse.
        :rtype: str
        """
        return self._desc

    @desc.setter
    def desc(self, desc):
        """Sets the desc of this ShowResourceResponse.


        :param desc: The desc of this ShowResourceResponse.
        :type desc: str
        """
        self._desc = desc

    @property
    def directory(self):
        """Gets the directory of this ShowResourceResponse.

        资源所在目录

        :return: The directory of this ShowResourceResponse.
        :rtype: str
        """
        return self._directory

    @directory.setter
    def directory(self, directory):
        """Sets the directory of this ShowResourceResponse.

        资源所在目录

        :param directory: The directory of this ShowResourceResponse.
        :type directory: str
        """
        self._directory = directory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResourceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdgc-3.1.92-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/show_resource_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResourceResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'location': 'str',
        'depend_files': 'list[str]',
        'desc': 'str',
        'directory': 'str',
        'depend_packages': 'list[DependPackage]',
        'job_relation': 'list[Relation]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'location': 'location',
        'depend_files': 'dependFiles',
        'desc': 'desc',
        'directory': 'directory',
        'depend_packages': 'dependPackages',
        'job_relation': 'jobRelation'
    }

    def __init__(self, id=None, name=None, type=None, location=None, depend_files=None, desc=None, directory=None, depend_packages=None, job_relation=None):
        """ShowResourceResponse

        The model defined in huaweicloud sdk

        :param id: 资源id
        :type id: str
        :param name: 资源名称，只能包含英文字母、数字、中文字符、下划线或中划线。
        :type name: str
        :param type: 资源类型:   - archive: 压缩包   - file: 文件   - jar: jar文件   - pyFile：python文件
        :type type: str
        :param location: 资源文件所在OBS路径
        :type location: str
        :param depend_files: 主Jar包所依赖的JAR包、properties文件
        :type depend_files: list[str]
        :param desc: 资源描述
        :type desc: str
        :param directory: 资源所在目录
        :type directory: str
        :param depend_packages: 主Jar包所依赖的JAR包、properties文件。同时存在dependFiles和dependPackages时，优先解析该字段。
        :type depend_packages: list[:class:`huaweicloudsdkdgc.v1.DependPackage`]
        :param job_relation: 通过jar包名称查询相关的job
        :type job_relation: list[:class:`huaweicloudsdkdgc.v1.Relation`]
        """
        
        super(ShowResourceResponse, self).__init__()

        self._id = None
        self._name = None
        self._type = None
        self._location = None
        self._depend_files = None
        self._desc = None
        self._directory = None
        self._depend_packages = None
        self._job_relation = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if location is not None:
            self.location = location
        if depend_files is not None:
            self.depend_files = depend_files
        if desc is not None:
            self.desc = desc
        if directory is not None:
            self.directory = directory
        if depend_packages is not None:
            self.depend_packages = depend_packages
        if job_relation is not None:
            self.job_relation = job_relation

    @property
    def id(self):
        """Gets the id of this ShowResourceResponse.

        资源id

        :return: The id of this ShowResourceResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShowResourceResponse.

        资源id

        :param id: The id of this ShowResourceResponse.
        :type id: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this ShowResourceResponse.

        资源名称，只能包含英文字母、数字、中文字符、下划线或中划线。

        :return: The name of this ShowResourceResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShowResourceResponse.

        资源名称，只能包含英文字母、数字、中文字符、下划线或中划线。

        :param name: The name of this ShowResourceResponse.
        :type name: str
        """
        self._name = name

    @property
    def type(self):
        """Gets the type of this ShowResourceResponse.

        资源类型:   - archive: 压缩包   - file: 文件   - jar: jar文件   - pyFile：python文件

        :return: The type of this ShowResourceResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowResourceResponse.

        资源类型:   - archive: 压缩包   - file: 文件   - jar: jar文件   - pyFile：python文件

        :param type: The type of this ShowResourceResponse.
        :type type: str
        """
        self._type = type

    @property
    def location(self):
        """Gets the location of this ShowResourceResponse.

        资源文件所在OBS路径

        :return: The location of this ShowResourceResponse.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ShowResourceResponse.

        资源文件所在OBS路径

        :param location: The location of this ShowResourceResponse.
        :type location: str
        """
        self._location = location

    @property
    def depend_files(self):
        """Gets the depend_files of this ShowResourceResponse.

        主Jar包所依赖的JAR包、properties文件

        :return: The depend_files of this ShowResourceResponse.
        :rtype: list[str]
        """
        return self._depend_files

    @depend_files.setter
    def depend_files(self, depend_files):
        """Sets the depend_files of this ShowResourceResponse.

        主Jar包所依赖的JAR包、properties文件

        :param depend_files: The depend_files of this ShowResourceResponse.
        :type depend_files: list[str]
        """
        self._depend_files = depend_files

    @property
    def desc(self):
        """Gets the desc of this ShowResourceResponse.

        资源描述

        :return: The desc of this ShowResourceResponse.
        :rtype: str
        """
        return self._desc

    @desc.setter
    def desc(self, desc):
        """Sets the desc of this ShowResourceResponse.

        资源描述

        :param desc: The desc of this ShowResourceResponse.
        :type desc: str
        """
        self._desc = desc

    @property
    def directory(self):
        """Gets the directory of this ShowResourceResponse.

        资源所在目录

        :return: The directory of this ShowResourceResponse.
        :rtype: str
        """
        return self._directory

    @directory.setter
    def directory(self, directory):
        """Sets the directory of this ShowResourceResponse.

        资源所在目录

        :param directory: The directory of this ShowResourceResponse.
        :type directory: str
        """
        self._directory = directory

    @property
    def depend_packages(self):
        """Gets the depend_packages of this ShowResourceResponse.

        主Jar包所依赖的JAR包、properties文件。同时存在dependFiles和dependPackages时，优先解析该字段。

        :return: The depend_packages of this ShowResourceResponse.
        :rtype: list[:class:`huaweicloudsdkdgc.v1.DependPackage`]
        """
        return self._depend_packages

    @depend_packages.setter
    def depend_packages(self, depend_packages):
        """Sets the depend_packages of this ShowResourceResponse.

        主Jar包所依赖的JAR包、properties文件。同时存在dependFiles和dependPackages时，优先解析该字段。

        :param depend_packages: The depend_packages of this ShowResourceResponse.
        :type depend_packages: list[:class:`huaweicloudsdkdgc.v1.DependPackage`]
        """
        self._depend_packages = depend_packages

    @property
    def job_relation(self):
        """Gets the job_relation of this ShowResourceResponse.

        通过jar包名称查询相关的job

        :return: The job_relation of this ShowResourceResponse.
        :rtype: list[:class:`huaweicloudsdkdgc.v1.Relation`]
        """
        return self._job_relation

    @job_relation.setter
    def job_relation(self, job_relation):
        """Sets the job_relation of this ShowResourceResponse.

        通过jar包名称查询相关的job

        :param job_relation: The job_relation of this ShowResourceResponse.
        :type job_relation: list[:class:`huaweicloudsdkdgc.v1.Relation`]
        """
        self._job_relation = job_relation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResourceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
